@@ -2,6 +2,9 @@ import gdown
 
 from .efficient_sam import EfficientSam
 from .segment_anything_model import SegmentAnythingModel
+from .text_to_annotation import get_rectangles_from_texts  # NOQA: F401
+from .text_to_annotation import get_shapes_from_annotations  # NOQA: F401
+from .text_to_annotation import non_maximum_suppression  # NOQA: F401
 
 
 class SegmentAnythingModelVitB(SegmentAnythingModel):
