@@ -1,8 +1,7 @@
 import imgviz
 import numpy as np
 import skimage
-
-from labelme.logger import logger
+from loguru import logger
 
 
 def _get_contour_length(contour):
