@@ -7,8 +7,7 @@ import uuid
 import numpy as np
 import PIL.Image
 import PIL.ImageDraw
-
-from labelme.logger import logger
+from loguru import logger
 
 
 def polygons_to_mask(img_shape, polygons, shape_type=None):
@@ -76,7 +75,7 @@ def shapes_to_label(img_shape, shapes, label_name_to_value):
 
 
 def labelme_shapes_to_label(img_shape, shapes):
-    logger.warn(
+    logger.warning(
         "labelme_shapes_to_label is deprecated, so please use " "shapes_to_label."
     )
 
