@@ -1,11 +1,15 @@
 # flake8: noqa
 
+from .ai_prompt_widget import AiPromptWidget
+
 from .brightness_contrast_dialog import BrightnessContrastDialog
 
 from .canvas import Canvas
 
 from .color_dialog import ColorDialog
 
+from .file_dialog_preview import FileDialogPreview
+
 from .label_dialog import LabelDialog
 from .label_dialog import LabelQLineEdit
 
