@@ -1,4 +1,7 @@
+import contextlib
+
 import imgviz
+from loguru import logger
 from qtpy import QtCore
 from qtpy import QtGui
 from qtpy import QtWidgets
@@ -6,7 +9,6 @@ from qtpy import QtWidgets
 import labelme.ai
 import labelme.utils
 from labelme import QT5
-from labelme.logger import logger
 from labelme.shape import Shape
 
 # TODO(unknown):
@@ -137,7 +139,18 @@ class Canvas(QtWidgets.QWidget):
             logger.debug("AI model is already initialized: %r" % model.name)
         else:
             logger.debug("Initializing AI model: %r" % model.name)
-            self._ai_model = model()
+
+            class LoggerIO:
+                def write(self, message: str):
+                    if message := message.strip():
+                        logger.debug(message)
+
+                def flush(self):
+                    pass
+
+            # NOTE: gdown.download uses sys.stderr, so redirect it to logger.debug
+            with contextlib.redirect_stderr(new_target=LoggerIO()):
+                self._ai_model = model()
 
         if self.pixmap is None:
             logger.warning("Pixmap is not set yet")
@@ -331,8 +344,8 @@ class Canvas(QtWidgets.QWidget):
         for shape in reversed([s for s in self.shapes if self.isVisible(s)]):
             # Look for a nearby vertex to highlight. If that fails,
             # check if we happen to be inside a shape.
-            index = shape.nearestVertex(pos, self.epsilon / self.scale)
-            index_edge = shape.nearestEdge(pos, self.epsilon / self.scale)
+            index = shape.nearestVertex(pos, self.epsilon)
+            index_edge = shape.nearestEdge(pos, self.epsilon)
             if index is not None:
                 if self.selectedVertex():
                     self.hShape.highlightClear()
@@ -342,7 +355,12 @@ class Canvas(QtWidgets.QWidget):
                 self.hEdge = None
                 shape.highlightVertex(index, shape.MOVE_VERTEX)
                 self.overrideCursor(CURSOR_POINT)
-                self.setToolTip(self.tr("Click & drag to move point"))
+                self.setToolTip(
+                    self.tr(
+                        "Click & Drag to move point\n"
+                        "ALT + SHIFT + Click to delete point"
+                    )
+                )
                 self.setStatusTip(self.toolTip())
                 self.update()
                 break
@@ -354,7 +372,7 @@ class Canvas(QtWidgets.QWidget):
                 self.prevhShape = self.hShape = shape
                 self.prevhEdge = self.hEdge = index_edge
                 self.overrideCursor(CURSOR_POINT)
-                self.setToolTip(self.tr("Click to create point"))
+                self.setToolTip(self.tr("ALT + Click to create point"))
                 self.setStatusTip(self.toolTip())
                 self.update()
                 break
@@ -466,13 +484,11 @@ class Canvas(QtWidgets.QWidget):
                         self.drawingPolygon.emit(True)
                         self.update()
             elif self.editing():
-                if self.selectedEdge():
+                if self.selectedEdge() and ev.modifiers() == QtCore.Qt.AltModifier:
                     self.addPointToEdge()
-                elif (
-                    self.selectedVertex()
-                    and int(ev.modifiers()) == QtCore.Qt.ShiftModifier
+                elif self.selectedVertex() and ev.modifiers() == (
+                    QtCore.Qt.AltModifier | QtCore.Qt.ShiftModifier
                 ):
-                    # Delete point if: left-click + SHIFT on a point
                     self.removeSelectedPoint()
 
                 group_mode = int(ev.modifiers()) == QtCore.Qt.ControlModifier
@@ -663,23 +679,6 @@ class Canvas(QtWidgets.QWidget):
         self.storeShapes()
         self.update()
 
-    def duplicateSelectedShapes(self):
-        if self.selectedShapes:
-            self.selectedShapesCopy = [s.copy() for s in self.selectedShapes]
-            self.boundedShiftShapes(self.selectedShapesCopy)
-            self.endMove(copy=True)
-        return self.selectedShapes
-
-    def boundedShiftShapes(self, shapes):
-        # Try to move in one direction, and if it fails in another.
-        # Give up if both fail.
-        point = shapes[0][0]
-        offset = QtCore.QPointF(2.0, 2.0)
-        self.offsets = QtCore.QPoint(), QtCore.QPoint()
-        self.prevPoint = point
-        if not self.boundedMoveShapes(shapes, point - offset):
-            self.boundedMoveShapes(shapes, point + offset)
-
     def paintEvent(self, event):
         if not self.pixmap:
             return super(Canvas, self).paintEvent(event)
@@ -695,6 +694,8 @@ class Canvas(QtWidgets.QWidget):
 
         p.drawPixmap(0, 0, self.pixmap)
 
+        p.scale(1 / self.scale, 1 / self.scale)
+
         # draw crosshair
         if (
             self._crosshair[self._createMode]
@@ -705,14 +706,14 @@ class Canvas(QtWidgets.QWidget):
             p.setPen(QtGui.QColor(0, 0, 0))
             p.drawLine(
                 0,
-                int(self.prevMovePoint.y()),
+                int(self.prevMovePoint.y() * self.scale),
                 self.width() - 1,
-                int(self.prevMovePoint.y()),
+                int(self.prevMovePoint.y() * self.scale),
             )
             p.drawLine(
-                int(self.prevMovePoint.x()),
+                int(self.prevMovePoint.x() * self.scale),
                 0,
-                int(self.prevMovePoint.x()),
+                int(self.prevMovePoint.x() * self.scale),
                 self.height() - 1,
             )
 
