@@ -1,12 +1,12 @@
 import re
 
+from loguru import logger
 from qtpy import QT_VERSION
 from qtpy import QtCore
 from qtpy import QtGui
 from qtpy import QtWidgets
 
 import labelme.utils
-from labelme.logger import logger
 
 QT5 = QT_VERSION[0] == "5"
 
@@ -106,7 +106,7 @@ class LabelDialog(QtWidgets.QDialog):
         # completion
         completer = QtWidgets.QCompleter()
         if not QT5 and completion != "startswith":
-            logger.warn(
+            logger.warning(
                 "completion other than 'startswith' is only "
                 "supported with Qt5. Using 'startswith'"
             )
@@ -134,6 +134,10 @@ class LabelDialog(QtWidgets.QDialog):
         self.edit.setText(item.text())
 
     def validate(self):
+        if not self.edit.isEnabled():
+            self.accept()
+            return
+
         text = self.edit.text()
         if hasattr(text, "strip"):
             text = text.strip()
